************************************************************************
* File (bbbb_main_11_11.F).
************************************************************************
* This file is the main module of FORTRAN code
* to calculate "A + A -> A + A" EW + QED cross-section.
*
* The file is produced by s2n package of SANC (v1.10) project.
* Copyright, SANC Project Team, 2005-2009.
*
* http://sanc.jinr.ru/
* http://pcphsanc.cern.ch/
* E-mail: <sanc@jinr.ru>
************************************************************************
      program bbbb_main_11_11
      implicit none!
#include "s2n_declare_r16.h"

      integer ome,lmu,imu,isetup,is,ic,steps,ii,jj,imlc,ihard,intscheme
      integer ncall,itmx,nprn,ndev
      real*16 sq,born_sd,virt_sd
      real*16 xl(10),xu(10),acc,dummy,avgi,sd,chi2a
      real*16 mlc,ranini,Mfscale,EXP,LOG,start,awc
      real*16 XMIN,XMAX,STEP,EPS,ABS,FINDX,ARG,RE2,RE3,function_1c_11_11
      common /bveg1/ ncall, itmx, nprn, ndev, xl, xu, acc
      common /s/s
      common /awc/awc
      common /Mfscale/Mfscale
      external function_1c_11_11,FINDX

*
*   iha      = 0   total helicities sum
*              1   ++ helicities sum
*              2   +- helicities sum
*
*   iqed     = 0   without QED corrections
*              1   with 
*
*   iew      = 0   without Weak corrections
*              1   with
*
*   gfscheme = 0   alpha(0) calculation scheme
*              1   GF
*              2   GF prime
*                
*   isetup   = 0   SANC input [PDG 2006]            CPC 177 (2007) 623
*              1   Les Houches Workshop (2005)      [hep-ph/0604120]
*              2   Tevatron-for-LHC Workshop (2006) [arXiv:0705.3251]
*              3   Custum setup
*
*   start = 1q-5   logarithmic scale sqrt(s) from 0.1MeV to 1GeV      
*           1q-1   logarithmic scale sqrt(s) from 1GeV to 10^4 GeV      
*
*****************************************SET FLAGS!
      iha  = 0
      iqed = 1
      iew  = 1
      gfscheme = 0
      isetup = 3
      start = 1q-1
*****************************************SET FLAGS!

      intscheme = 0
      nc = 1q0
      fc = 1q0

      if (isetup.eq.0) then
#include "sanc_input.h"
         print *, "SANC setup"
      elseif (isetup.eq.1) then
#include "leshw_input.h"
         print *, "Les Houches setup"
      elseif (isetup.eq.2) then
#include "tev4lhcw_input.h"
         print *, "TeV4LHC setup"
      elseif (isetup.eq.3) then
#include "custom_input.h"
         print *, "Custom setup"
      endif

*      call ffini()
      call s2n_init_r16()

      print *
      print *, "flag ha     = ",iha
      print *, "flag qed    = ",iqed
      print *, "flag ew     = ",iew
      print *, "gfscheme    = ",gfscheme
      print *, "flag ilin   = ",ilin
      print *, "flag ifgg   = ",ifgg
      print *, "flag ihard  = ",ihard
      print *, "flag isetup = ",isetup
      print *
      print *, "alphai    = ",alphai
      print *, "alpha     = ",alpha
      print *, "GF(GeV-^2)= ",gf
      print *, "g         = ",g
      print *, "e         = ",e
      print *, "cwm       = ",ctw
      print *, "swm2      = ",stw2
      print *, "mh(GeV)   = ",mh
      print *, "mw(GeV)   = ",mw
      print *, "mz(GeV)   = ",mz
      print *, "wz(GeV)   = ",wz
      print *, "ww(GeV)   = ",ww
      print *, "wh(GeV)   = ",wh
      print *, "wtp(GeV)  = ",wtp
      print *, "IntScheme = ",intscheme
      print *, ""
      print *, "Proccess  a + a --> a + a";

      do imu=1,1
      if(imu.eq.1) thmu = mw
      if(imu.eq.2) thmu = mw/10
      do lmu=2,2
      if(lmu.eq.1) tlmu2 = 1/10
      if(lmu.eq.2) tlmu2 = 1/100
      thmu2 = thmu**2
      print *, ''
      print *, "thmu(GeV)    = ", thmu
      print *, "thla2(GeV^2) = ", tlmu2

      nprn = -1
      dummy = ranini(192837465)

      if ((iqed.eq.1).and.(iew.eq.0)) then
      open(1,file="4A_qed_r16.dat")
      endif
      if ((iew.eq.1).and.(iqed.eq.0)) then
      open(1,file="4A_ew_r16.dat")
      endif
      if ((iqed.eq.1).and.(iew.eq.1)) then
      close(1)
      open(1,file="4A_sm_r16.dat")
      endif

* AUTO EDIT PARAMETERS
      AWC = 1q-10
      EPS = pi/6
* AUTO EDIT PARAMETERS
* EPS < f < \pi-EPS
* AWC = - T/S - D0 function shift from zero for limit answer

* Logarithmic Scale for sqrt(s)
      steps = 100
      do ic=1,4
       start = start*10q0
      do is=1,100
         sq = start*(EXP(LOG(10Q0)*(is-1Q0)/steps)) 
         s  = sq**2

      if (intscheme.eq.0) then
*     vegas
         xl(1) = 0q0 + EPS
         xu(1) = pi  - EPS
         ncall = 500 !1000
         itmx = 10
         call vegas (1, function_1c_11_11, avgi, sd, chi2a)
         itmx = 10
         call vegas1 (1, function_1c_11_11, avgi, sd, chi2a)
         virt = avgi
         virt_sd = sd
      endif

         write(1,11) sq, virt, virt_sd
11         format(1x,f25.10,3x,e25.15,3x,e25.15)

         print *, ""
         print *, "sq(GeV)        = ", sq
         print *, "[1loop](pb)    = ", virt, virt_sd
      enddo
      enddo
      close(1)
      
      enddo
      enddo

      stop
      end
***************************************************************
      real*16 function function_1c_11_11(x,wgt)
      implicit none!
#include "s2n_declare_r16.h"
      real*16 x(10),wgt
      common /s/s

      t = -s*(sin(x(1)/2))**2
      u = -s*(cos(x(1)/2))**2
      if (iborn.eq.1) then
         call bbbb_ha_11_11 (s,t,u,born)
         function_1c_11_11 = born*sin(x(1))
         return
      elseif (iborn.eq.0) then
         call bbbb_ha_11_11 (s,t,u,sigma)
         function_1c_11_11 = sigma*sin(x(1))
         return
      else
         print *, "wrong iborn values = ", iborn
         function_1c_11_11 = 0q0
      endif

      return
      end
***************************************************************
